@@ -112,11 +112,12 @@ def get_news():
         a+=1
     print("\033[0m")
 
-def printf(text):
+def printf(text,ts=0.1):
     text=str(text)
     for i in text:
         print(i,end='')
-        time.sleep(0.1)
+        time.sleep(ts)
 def cleardevice():
-    print("\033[2J")
-    print("\033[99999999999999999999999999999999A", end='')
+    import sys
+    sys.stdout.write("\033[2J\033[00H")
+
